@@ -75,7 +75,7 @@ phe_rate <- function(data,x, n, type = "full", confidence = 0.95, multiplier = 1
 
 
     # if data is grouped then summarise
-    if(!is.null(groups(data))) {
+    if(!n_groups(data) == 1) {
         data <- data %>%
                 summarise({{ x }} := sum({{ x }}),
                           {{ n }} := sum({{ n }}))
